@@ -1072,11 +1072,13 @@ int lp_interval_size_approx(const lp_interval_t* I) {
 }
 
 char* lp_interval_to_string(const lp_interval_t* I) {
+  struct u_memstream mem;
   char* str = 0;
   size_t size = 0;
-  FILE* f = open_memstream(&str, &size);
+  u_memstream_open(&mem, &str, &size);
+  FILE* f = u_memstream_get(&mem);
   lp_interval_print(I, f);
-  fclose(f);
+  u_memstream_close(&mem);
   return str;
 }
 
